/*!
  \file
  \brief テーマ時計の設定ダイアログ

  \author Satofumi KAMIMURA

  $Id$

  \todo シグナルを定義する
*/

#include "ClockSettingDialog.h"


struct ClockSettingDialog::pImpl {

  void initializeForm(ClockSettingDialog* parent) {

    // 拡大率の変更
    // !!!
  }
};


ClockSettingDialog::ClockSettingDialog(QDialog* parent)
  : QDialog(parent), pimpl(new pImpl) {
  setupUi(this);

  pimpl->initializeForm(this);
}


ClockSettingDialog::~ClockSettingDialog(void) {
}


// !!! 拡大率スライダの処理ハンドラ
